OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Учитавам преглед…",
    "Saved" : "Сачувано",
    "Admin" : "Администрација",
    "a safe home for all your data" : "сигурно место за све ваше податке",
    "Name cannot be empty" : "Назив не може бити празан",
    "The given name is too long" : "Назив је предугачак",
    "The given web address is too long" : "Наведена веб адреса је предугачка",
    "The given web address is not a valid URL" : "Наведена веб адреса није исправан УРЛ",
    "The given legal notice address is too long" : "Адреса правног обавештења је предугачка",
    "The given legal notice address is not a valid URL" : "Адреса правног обавештења није исправан УРЛ",
    "The given privacy policy address is too long" : "Адреса смерница приватности је предугачка",
    "The given privacy policy address is not a valid URL" : "Адреса смерница приватности није исправан УРЛ",
    "The given slogan is too long" : "Слоган је предугачак",
    "The given color is invalid" : "Задата боја није исправна",
    "The file was uploaded" : "Фајл је отпремљен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Отпремани фајл превазилази смерницу upload_max_filesize у фајлу php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Отпремани фајл превазилази смерницу MAX_FILE_SIZE наведену у ХТМЛ обрасцу",
    "The file was only partially uploaded" : "Фајл је само делимично отпремљен",
    "No file was uploaded" : "Није отпремљен фајл",
    "Missing a temporary folder" : "Недостаје привремена фасцикла",
    "Could not write file to disk" : "Не могу да упишем фајл на диск",
    "A PHP extension stopped the file upload" : "ПХП екстензија је зауставила отпремање фајла",
    "No file uploaded" : "Није отпремљен фајл",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Већ користите прилагођену тему. Поставке ове апликације ће прегажене са њом.",
    "Theming" : "Изглед",
    "Legal notice" : "Правно обавештење",
    "Privacy policy" : "Смернице приватности",
    "Adjust the Nextcloud theme" : "Прилагоди Некстклауд тему",
    "Open documentation" : "Отвори документацију",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Омогућава да лако измените изглед и угођај вашег Некстклауда. Ово ће бити видљиво свим корисницима.",
    "Name" : "Назив",
    "Reset to default" : "Врати на подразумевано",
    "Web link" : "Веб веза",
    "https://…" : "https://…",
    "Slogan" : "Слоган",
    "Color" : "Боја",
    "Logo" : "Лого",
    "Upload new logo" : "Отпремите нови лого",
    "Login image" : "Пријавна слика",
    "Upload new login background" : "Отпремите нову позадину за пријавни екран",
    "Remove background image" : "Уклони позадинску слику",
    "Advanced options" : "Напредне опције",
    "Legal notice link" : "Правно обавештење",
    "Privacy policy link" : "Смернице приватности",
    "Header logo" : "Лого заглавља",
    "Upload new header logo" : "Отпремите нови лого заглавља",
    "Favicon" : "Икона веб стране",
    "Upload new favicon" : "Отпремите нову иконицу",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Инсталирајте „Imagemagick“ ПХП екстензију са подршком за СВГ слике, да аутоматски направи иконе од отпремљеног логоа и боје.",
    "Unsupported image type" : "Неподржани тип слике"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
